@@ -167,6 +167,18 @@ class FlashScope(object):
         for key, value in kwargs.items():
             self[key] = value
 
+    def add(self, key, value):
+        """Appends a value to a key in this flash.
+        """
+        if key in self:
+            current_value = self[key]
+            if not isinstance(current_value, list):
+                self[key] = [current_value, value]
+            else:
+                current_value.append(value)
+        else:
+            self[key] = [value]
+
     def clear(self):
         """Removes all items from this flash.
         """
@@ -176,7 +188,7 @@ class FlashScope(object):
     def put_immediate(self, key, value):
         """Puts a value inside this flash and marks it as *used*.
         """
-        self._session[key] = value
+        self[key] = value
         self._update_status(key)
 
     def discard(self, *keys):
