@@ -3,6 +3,7 @@
 """Integration test cases.
 """
 
+from django.conf import settings
 from django.core.exceptions import SuspiciousOperation
 from django.core.urlresolvers import reverse
 from django.test import TestCase
@@ -52,6 +53,23 @@ class IntegrationTestCase(TestCase):
         self.response = self.client.get(reverse(views.render_template))
         self.assertFalse('message' in self._flash())
 
+    def test_keep_decorator(self):
+        """Integration: keep_messages decorator should behave exactly like keep.
+        """
+        self.response = self.client.get(reverse(views.set_flash_var))
+        self.assertEqual('Message', self._flash()['message'])
+
+        self.response = self.client.get(reverse(views.keep_var_decorator))
+        self.assertEqual('Message', self._flash()['message'])
+
+        # Flash value won't be removed now because it was explicitely kept
+        self.response = self.client.get(reverse(views.render_template))
+        self.assertEqual('Message', self._flash()['message'])
+
+        # Flash value will be removed when this request hits the app
+        self.response = self.client.get(reverse(views.render_template))
+        self.assertFalse('message' in self._flash())
+
     def test_now_lifecycle(self):
         """Integration: an immediate value shouldn't survive the next request.
         """
@@ -102,3 +120,38 @@ class IntegrationTestCase(TestCase):
         """Integration: an exception should be raised when exposing an invalid object as being the flash.
         """
         self.assertRaises(SuspiciousOperation, self.client.get, reverse(views.replace_flash))
+
+    def test_request_to_serve_view_without_ignore(self):
+        """Integration: request to static resources should trigger the flash update.
+        """
+        self.response = self.client.get(reverse(views.set_flash_var))
+        self.assertEqual('Message', self._flash()['message'])
+
+        # Requests to static resources should trigger the flash update
+        settings.FLASH_IGNORE_MEDIA = False
+
+        self.response = self.client.get(settings.MEDIA_URL + 'test.css')
+        self.assertEqual(200, self.response.status_code)
+
+        # Flash value will be removed when this request hits the app
+        self.response = self.client.get(reverse(views.render_template))
+        self.assertFalse('message' in self._flash())
+
+    def test_request_to_serve_view_with_ignore(self):
+        """Integration: request to static resources should not trigger the flash update, if properly configured.
+        """
+        self.response = self.client.get(reverse(views.set_flash_var))
+        self.assertEqual('Message', self._flash()['message'])
+
+        # Requests to static resources should not trigger the flash update
+        settings.FLASH_IGNORE_MEDIA = True
+        
+        self.response = self.client.get(settings.MEDIA_URL + 'test.css')
+        self.assertEqual(200, self.response.status_code)
+
+        self.response = self.client.get(reverse(views.render_template))
+        self.assertEqual('Message', self._flash()['message'])
+
+        # Flash value will be removed when this request hits the app
+        self.response = self.client.get(reverse(views.render_template))
+        self.assertFalse('message' in self._flash())
